@@ -54,9 +54,16 @@ from sollol.docker_ip_resolver import (
 
 # Distributed inference
 from sollol.hybrid_router import HybridRouter
+from sollol.ray_hybrid_router import RayHybridRouter
+from sollol.ray_advanced_router import RayAdvancedRouter
 from sollol.llama_cpp_coordinator import LlamaCppCoordinator
 from sollol.llama_cpp_rpc import LlamaCppDistributedCluster, LlamaCppRPCClient
 
+# Monitoring & Dashboards
+from sollol.unified_dashboard import UnifiedDashboard, run_unified_dashboard
+from sollol.distributed_tracing import DistributedTracer, get_tracer
+from sollol.dashboard_client import DashboardClient
+
 # Distributed execution
 from sollol.execution import AsyncDistributedExecutor, DistributedExecutor
 from sollol.tasks import DistributedTask, ExecutionResult, TaskResult
@@ -70,16 +77,24 @@ from sollol.rpc_registry import RPCBackendRegistry
 # Legacy support
 from sollol.sollol import SOLLOL
 
-__version__ = "0.8.1"
+__version__ = "0.9.5"
 __all__ = [
     # Core
     "OllamaPool",
     "SOLLOLClient",
     # Distributed inference
     "HybridRouter",
+    "RayHybridRouter",
+    "RayAdvancedRouter",
     "LlamaCppRPCClient",
     "LlamaCppDistributedCluster",
     "LlamaCppCoordinator",
+    # Monitoring & Dashboards
+    "UnifiedDashboard",
+    "run_unified_dashboard",
+    "DistributedTracer",
+    "get_tracer",
+    "DashboardClient",
     # Distributed execution
     "DistributedExecutor",
     "AsyncDistributedExecutor",
